#ifndef UU_COPY_H
#define UU_COPY_H

#include "uulib/UUID.h"

void uu_copy_binary(const uu_t in, uu_t out);
void uu_copy_struct(const struct uu *in, struct uu *out);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
